@@ -1,4 +1,4 @@
-import os, random, sys, cv2, time, csv, pickle, re
+import os, random, sys, cv2, time, csv, pickle, re, pkg_resources
 os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 from tkinter import StringVar, DoubleVar, Tk, Label, Entry, Button, OptionMenu, Checkbutton, Message, Menu, IntVar, Scale, HORIZONTAL
 from tkinter.ttk import Progressbar, Separator, Combobox
@@ -9,27 +9,22 @@ from scipy.io.wavfile import write as wavwrite
 from scipy.optimize import nnls
 from scipy.interpolate import interp1d
 from scipy.signal import resample
-from pygame.mixer import Sound, init, quit, get_init, set_num_channels, pre_init, music
+from pygame.mixer import init, quit, get_init, set_num_channels, pre_init, music
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 import matplotlib.ticker as tkr
-import matplotlib.cm as cmaps
-#https://matplotlib.org/gallery/color/colormap_reference.html
+import matplotlib.cm as cmaps # https://matplotlib.org/gallery/color/colormap_reference.html
 import numpy as np
 from numpy.matlib import repmat
-from soundfile import read
-from midiutil import MIDIFile
+from soundfile import read # marked for deletion
+from midiutil import MIDIFile # need to move to MIDO for noteon/noteoff
 try:
 	from pyanthem.pyanthem_vars import *
 except:
 	from pyanthem_vars import *
 from git import Repo
-import pkg_resources
 from google_drive_downloader import GoogleDriveDownloader as gdd
 
-
-print('pyanthem version {}'.format(pkg_resources.require("pyanthem")[0].version))
-
 def AE_download():
 	'''
 	Downloads the 'Piano' audio engine from  
@@ -117,6 +112,7 @@ def run(display=True):
 	'''
 	main command to run GUI or CLI
 	'''
+	print('pyanthem version {}'.format(pkg_resources.require("pyanthem")[0].version))
 	root = GUI(display=display)
 	if display:
 		root.mainloop()
@@ -336,7 +332,7 @@ class GUI(Tk):
 		# Making note matrix
 		true_fr = self.cfg['fr']*self.cfg['speed']/100
 		ns = int(len(self.data['H_pp'].T)*1000/true_fr)
-		H = resample(self.data['H_pp'], ns, axis=1)
+		H = resample(self.data['H_pp'], ns, axis=1) #need to change to interp1d
 		Hb = H > self.cfg['threshold']
 		Hb = Hb * 1
 		Hb[:,0] = 0
@@ -403,38 +399,42 @@ class GUI(Tk):
 		'''
 		
 		'''
-		fn_font = os.path.join(self.package_path,'anthem_soundfonts',self.audio_format.get())
-		fn_midi = os.path.join(self.package_path,'preview.mid')
-		fn_wav = os.path.join(self.package_path,'preview.wav')
-		if not hasattr(self,'data'):
-			self.status['text'] = 'Status: Cannot do this - no dataset has been loaded.'
-			return
-		if get_init() is None: # Checks if pygame has initialized audio engine. Only needs to be run once per instance
-			pre_init(44100, -16, 2, 1024)
-			init()
-			set_num_channels(128) # We will never need more than 128...
-		MIDI = MIDIFile(1)  # One track
-		MIDI.addTempo(0,0,60) # addTempo(track, time, tempo)
-		for i in range(len(self.keys)):
-			MIDI.addNote(0, 0, self.keys[i], i/2, .5, 100)
-		with open(fn_midi, 'wb') as mid:
-			MIDI.writeFile(mid)
-		os.system('fluidsynth -ni {} {} -F {} -r 44100'.format(fn_font,fn_midi,fn_wav))
-		music.load(fn_wav)
-		for i in range(len(self.keys)):
-			t = time.time()
-			self.imW.remove()
-			Wtmp = self.data['W_pp'][:,i]
-			cmaptmp = self.cmap[i,:-1]
-			self.imW = self.Wax2.imshow((Wtmp[:,None]@cmaptmp[None,:]*255/np.max(self.data['W_pp'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
-			self.canvas_W.draw()
-			self.update()
-			if i == 0:
-				music.play(0)
-			time.sleep(.5-np.min(((time.time()-t),.5)))
-		os.remove(fn_midi)
-		os.remove(fn_wav)
-		self.refresh_GUI()
+		if self.audio_format.get().endswith('.sf2'):
+			self.make_keys()
+			fn_font = os.path.join(self.package_path,'anthem_soundfonts',self.audio_format.get())
+			fn_midi = os.path.join(self.package_path,'preview.mid')
+			fn_wav = os.path.join(self.package_path,'preview.wav')
+			if not hasattr(self,'data'):
+				self.status['text'] = 'Status: Cannot do this - no dataset has been loaded.'
+				return
+			if get_init() is None: # Checks if pygame has initialized audio engine. Only needs to be run once per instance
+				pre_init(44100, -16, 2, 1024)
+				init()
+				set_num_channels(128) # We will never need more than 128...
+			MIDI = MIDIFile(1)  # One track
+			MIDI.addTempo(0,0,60) # addTempo(track, time, tempo)
+			for i in range(len(self.keys)):
+				MIDI.addNote(0, 0, self.keys[i], i/2, .5, 100)
+			with open(fn_midi, 'wb') as mid:
+				MIDI.writeFile(mid)
+			cmd = 'fluidsynth -ni -F {} -r 44100 {} {} '.format(fn_wav,fn_font,fn_midi)
+			print(cmd)
+			os.system(cmd)
+			music.load(fn_wav)
+			for i in range(len(self.keys)):
+				t = time.time()
+				self.imW.remove()
+				Wtmp = self.data['W_pp'][:,i]
+				cmaptmp = self.cmap[i,:-1]
+				self.imW = self.Wax2.imshow((Wtmp[:,None]@cmaptmp[None,:]*255/np.max(self.data['W_pp'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
+				self.canvas_W.draw()
+				self.update()
+				if i == 0:
+					music.play(0)
+				time.sleep(.5-np.min(((time.time()-t),.5)))
+			os.remove(fn_midi)
+			os.remove(fn_wav)
+			self.refresh_GUI()
 
 	def write_audio(self):
 		'''
@@ -446,9 +446,9 @@ class GUI(Tk):
 			self.make_keys() # Just in case
 			if self.display:
 				self.dump_config()
-			if self.cfg['audio_format'] == 'MIDI' or self.cfg['audio_format'].endswith('.sf2'):
+			if self.cfg['audio_format'] is not 'Piano':
 				fn_midi = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mid'
-				fn_midi = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.wav'
+				fn_wav = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.wav'
 				MIDI = MIDIFile(1)  # One track
 				MIDI.addTempo(0,0,60) # addTempo(track, time, tempo)
 				for j in range(len(self.nd['note'])):
@@ -456,7 +456,9 @@ class GUI(Tk):
 					MIDI.addNote(0, 0, self.nd['note'][j], self.nd['st'][j], (self.nd['en'][j]-self.nd['st'][j]), self.nd['mag'][j])
 				with open(fn_midi, 'wb') as mid:
 					MIDI.writeFile(mid)
-				os.system('fluidsynth -ni {} {} -F {} -r 44100'.format(self.sound_font,fn_midi,fn_wav))
+				if self.cfg['audio_format'].endswith('.sf2'):
+					fn_sf = os.path.join(self.cfg['save_path'],'anthem_soundfonts',self.cfg['audio_format'])
+					os.system('fluidsynth -ni -F {} -r 44100 {} {}'.format(fn_wav,fn_sf,fn_midi))
 			elif self.cfg['audio_format'] == 'Piano':
 				self.synth()
 			elif self.cfg['audio_format'] == 'Stream':
